CodropCodec class

A standard Dart Codec for Codrop compression and decompression.

Inheritance

Constructors

CodropCodec({CodropLevel level = CodropLevel.balanced, int maxOutputBytes = 1024 * 1024 * 1024})
Creates a new CodropCodec.
const

Properties

decoder → Converter<List<int>, Uint8List>
Returns the decoder of this, converting from T to S.
no setteroverride
encoder → Converter<List<int>, Uint8List>
Returns the encoder from S to T.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
inverted → Codec<List<int>, List<int>>
Inverts this.
no setterinherited
level → CodropLevel
The compression profile level used when encoding.
final
maxOutputBytes → int
The maximum allowed decompressed bytes when decoding.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(List<int> encoded) → List<int>
Decodes encoded data.
inherited
encode(List<int> input) → List<int>
Encodes input.
inherited
fuse<R>(Codec<List<int>, R> other) → Codec<List<int>, R>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited