CodropLoader class
Manages loading and caching the libcodrop dynamic library.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- bindings → CodropBindings
-
Returns the active
CodropBindingsinstance, resolving it if necessary.no setter - isSupported → bool
-
Whether the native library is loaded or available on this platform.
no setter
Static Methods
-
initialize(
{String? libraryPath, DynamicLibrary? dynamicLibrary}) → void -
Explicitly initialize Codrop with a specific library path or loaded
DynamicLibrary. -
loadDynamicLibrary(
[String? customPath]) → DynamicLibrary - Discovers and opens the platform-appropriate dynamic library for Codrop.