CodropCodec class
A standard Dart Codec for Codrop compression and decompression.
Constructors
- CodropCodec({CodropLevel level = CodropLevel.balanced, int maxOutputBytes = 1024 * 1024 * 1024})
-
Creates a new CodropCodec.
const
Properties
-
decoder
→ Converter<
List< int> , Uint8List> -
Returns the decoder of
this, converting fromTtoS.no setteroverride -
encoder
→ Converter<
List< int> , Uint8List> -
Returns the encoder from
StoT.no setteroverride - hashCode → int
-
The hash code for this object.
no setterinherited
-
inverted
→ Codec<
List< int> , List<int> > -
Inverts
this.no setterinherited - level → CodropLevel
-
The compression profile level used when encoding.
final
- maxOutputBytes → int
-
The maximum allowed decompressed bytes when decoding.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(
List< int> encoded) → List<int> -
Decodes
encodeddata.inherited -
encode(
List< int> input) → List<int> -
Encodes
input.inherited -
fuse<
R> (Codec< List< other) → Codec<int> , R>List< int> , R> -
Fuses
thiswithother.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited